pub enum GridEdit {
InsertRows {
at: u32,
count: u32,
},
DeleteRows {
at: u32,
count: u32,
},
InsertColumns {
at: u32,
count: u32,
},
DeleteColumns {
at: u32,
count: u32,
},
}Expand description
A row or column insert/delete on a single sheet, described by the 1-based index of the first row/column affected and how many are inserted/deleted.
InsertRows { at: 3, count: 2 } inserts two blank rows so that they occupy
rows 3 and 4 and the old row 3 becomes row 5. DeleteRows { at: 3, count: 2 }
removes rows 3 and 4 so that the old row 5 becomes row 3.
count: 0 is a no-op; at: 0 is rejected (rows and columns are 1-based).
Variants
InsertRows
Insert count rows above the current row at.
DeleteRows
Delete the count rows starting at row at.
InsertColumns
Insert count columns to the left of the current column at.
DeleteColumns
Delete the count columns starting at column at.